# easy-archive
Quickly archive large media files

## Installation
```bash
pip install easy-archive
```

## Usage
```bash
easy-archive [archive] {archive_dir} --save_dir {save_dir} --num_files_per_archive {num_files_per_archive} --delete_original --overwrite --remove_duplicates --num_proc {num_proc}
easy-archive unarchive {archive_dir}
```
